@@ -293,6 +293,9 @@ def filters_to_sql(filters, default_tables={}):
                 except ValueError:
                     pass
 
+            elif operator == "IS" and value == "NULL":
+                value = f"NULL"
+
             elif isinstance(value, str):
                 # enclose string with quotes
                 value = f"'{value}'"
@@ -365,6 +368,9 @@ def filters_to_vql(filters):
                 except ValueError:
                     pass
 
+            elif operator == "IS" and value == "NULL":
+                value = f"NULL"
+
             elif isinstance(value, str):
                 value = f"'{value}'"
 
