@@ -1701,27 +1701,36 @@ class FiltersEditorWidget(plugin.PluginWidget):
         # self.save_button.setMinimumHeight(30)
         # self.del_button.setMinimumHeight(30)
 
+        self.apply_button = QPushButton(FIcon(0xF0233),self.tr("Apply filter"))
+        self.apply_button.clicked.connect(self.on_filters_changed)
         hlayout = QHBoxLayout()
         hlayout.addWidget(self.combo)
         hlayout.addWidget(self.save_button)
         hlayout.addWidget(self.del_button)
 
+        # setup Menu
+        self.add_button = self.toolbar.addAction(
+            FIcon(0xF0EF0), self.tr("Add Condition"), self.on_add_condition
+        )
+        spacer = QWidget()
+        spacer.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
+        self.toolbar.addWidget(spacer)
+
+        self.toolbar.addWidget(self.combo)
+        self.toolbar.addWidget(self.save_button)
+        self.toolbar.addWidget(self.del_button)
+
         layout = QVBoxLayout()
-        layout.addLayout(hlayout)
-        layout.addWidget(self.view)
+
         layout.addWidget(self.toolbar)
+        layout.addWidget(self.view)
+        layout.addWidget(self.apply_button)
         layout.setContentsMargins(0, 0, 0, 0)
         layout.setSpacing(1)
         self.setLayout(layout)
 
-        # setup Menu
-        self.add_button = self.toolbar.addAction(
-            FIcon(0xF0415), self.tr("Add Condition"), self.on_add_condition
-        )
-        spacer = QWidget()
-        spacer.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
-
-        self.model.filtersChanged.connect(self.on_filters_changed)
+     
+        #self.model.filtersChanged.connect(self.on_filters_changed)
 
     @property
     def filters(self):
