@@ -59,7 +59,6 @@ class VariantModel(QAbstractTableModel):
         self.total = 0
         self.variants = []
         self.headers = []
-        self.formatter = None
 
         # Cache all database fields and their descriptions for tooltips
         # Field names as keys, descriptions as values
@@ -123,16 +122,6 @@ class VariantModel(QAbstractTableModel):
             self.variant_runnable.error.connect(self.runnable_exception)
             self.count_runnable.error.connect(self.runnable_exception)
 
-    @property
-    def formatter(self):
-        return self._formatter
-
-    @formatter.setter
-    def formatter(self, formatter):
-        self.beginResetModel()
-        self._formatter = formatter
-        self.endResetModel()
-
     def rowCount(self, parent=QModelIndex()):
         """Overrided : Return children count of index"""
         # If parent is root
@@ -761,7 +750,7 @@ class VariantView(QWidget):
             # Yes it's hacky... but left pane doesn't show variants
             text = self.tr("{} group(s) {} page(s)")
         else:
-            text = self.tr("{} variant(s) {} page(s)")
+            text = self.tr("{} line(s) {} page(s)")
 
         self.info_label.setText(text.format(self.model.total, self.model.pageCount()))
 
@@ -1006,6 +995,23 @@ class VariantViewWidget(plugin.PluginWidget):
         self.groupbylist_action.setVisible(False)
         self.groupbylist_action.triggered.connect(self._show_group_dialog)
 
+        self.top_bar.addSeparator()
+        # Save selection
+        self.save_action = self.top_bar.addAction(
+            FIcon(0xF0F87), self.tr("Save selection"), self.on_save_selection
+        )
+        self.save_action.setToolTip(
+            self.tr("Save the current variants into a new selection")
+        )
+        # self.save_action.setPriority(QAction.LowPriority)
+
+        # Refresh UI button
+        action = self.top_bar.addAction(
+            FIcon(0xF0450), self.tr("Refresh"), self.on_refresh
+        )
+        action.setToolTip(self.tr("Refresh the current list of variants"))
+        # action.setPriority(QAction.LowPriority)
+
         # Formatter tools
         self.top_bar.addSeparator()
         spacer = QWidget()
@@ -1017,22 +1023,6 @@ class VariantViewWidget(plugin.PluginWidget):
         self.settings = QSettings()
         self.add_available_formatters()
 
-        # Refresh UI button
-        self.top_bar.addSeparator()
-        action = self.top_bar.addAction(
-            FIcon(0xF0450), self.tr("Refresh the list of variants"), self.on_refresh
-        )
-        action.setPriority(QAction.LowPriority)
-
-        # Save selection
-        self.save_action = self.top_bar.addAction(
-            FIcon(0xF0193), self.tr("Save selection"), self.on_save_selection
-        )
-        self.save_action.setToolTip(
-            self.tr("Save the current variants into a new selection")
-        )
-        self.save_action.setPriority(QAction.LowPriority)
-
         # Error handling
         self.log_edit = QLabel()
         self.log_edit.setMaximumHeight(30)
@@ -1079,17 +1069,18 @@ class VariantViewWidget(plugin.PluginWidget):
         Default formatter is "SeqoneFormatter".
         """
         # Get previously selected formatter
-        formatter_name = self.settings.value("ui/formatter", "SeqoneFormatter")
+        formatter_name = self.settings.value("ui/formatter", "CutestyleFormatter")
 
         # Add formatters to combobox, a click on it will instantiate the class
         selected_formatter_index = 0
         for index, obj in enumerate(formatter.find_formatters()):
-            self.formatter_combo.addItem(obj.DISPLAY_NAME, obj)
+            self.formatter_combo.addItem(FIcon(0xF03D8), obj.DISPLAY_NAME, obj)
             if obj.__name__ == formatter_name:
                 selected_formatter_index = index
 
         self.top_bar.addWidget(self.formatter_combo)
         self.formatter_combo.currentTextChanged.connect(self.on_formatter_changed)
+        self.formatter_combo.setToolTip(self.tr("Change current style"))
 
         # Set the previously used/default formatter
         self.formatter_combo.setCurrentIndex(selected_formatter_index)
@@ -1128,9 +1119,11 @@ class VariantViewWidget(plugin.PluginWidget):
         self._set_groups(self.mainwindow.state.group_by)
 
         # Set formatter
-        formatter_class = next(formatter.find_formatters())
-        self.main_right_pane.model.formatter = formatter_class()
-        self.groupby_left_pane.model.formatter = formatter_class()
+        formatter_class = self.formatter_combo.currentData()
+
+        #        formatter_class = next(formatter.find_formatters())
+        self.main_right_pane.set_formatter(formatter_class())
+        self.groupby_left_pane.set_formatter(formatter_class())
         # Load ui
         self.load()
 
